@@ -322,7 +322,22 @@ class ProctorservApi(object):
     response = rest.make_post_request(url, self.api_identifier, self.shared_secret, options) 
 
     return self.session_event_response(response)
-    
+
+  # Return a sessions launch parameters to launch proctorApp. Transitions a session into the
+  # 'checking_in' state
+  #
+  # options = OrderedDict([(String, specified_data_type)])
+  #   Required:
+  #    - 'session_id' (int) - Proctorserv id for the sessions whose launch parameters will be retrieved
+  # @returns an array of launch parameters
+  def get_launch_parameters(self, options):
+    self.requires_of(options, ['session_id'])
+    url = '%s://%s/api/sessions/get_launch_parameters' %(self.service_protocol, self.service_url)
+
+    rest = RestRequestClient()
+    response = rest.make_get_request(url, self.api_identifier, self.shared_secret, options)
+
+    return self.launch_parameters_response(response)
   
   def raise_exception_if_necessary(self, response):
     """ parses through an http response for error messages and raises appropriate exception """
@@ -454,6 +469,17 @@ class ProctorservApi(object):
     else:
       return False
 
+  def launch_parameters_response(self, response):
+    """ parses through an http response, returns launch parameters for
+    a specified session """
+    parsed_response = response.json()
+
+    if response.status_code == 200:
+      return parsed_response['launch_parameters']
+    elif response.status_code != 200:
+      self.raise_exceptions_if_necessary(parsed_response)
+    else:
+      return False
 
   def determine_jsonp_duration(self, options):
     """ determines the amount of time (in minutes) a user has 
