@@ -475,6 +475,30 @@ class AccessCodeTest(unittest.TestCase):
     print response
     self.assertFalse(response)
 
+class GetLaunchParametersTEst(unittest.TestCase):
+
+    def test_successful_call(self):
+        """return an array of a sessions launch parameters"""
+
+        proctorserv = ProctorservApi("customer_1","shared_secret","http", "localhost:3000")
+        options                               = collections.OrderedDict()
+        options['customer_subject_id']        = 'c_sub_1'
+        options['customer_client_subject_id'] = 'c_c_sub_1'
+        options['client_code']                = 'c_code'
+        options['reservation_id']             = 'res_id'
+        options['first_name']                 = 'Ryan'
+        options['last_name']                  = 'last'
+        options['session_duration']           = 60
+        options['exam_code']                  = '60'
+        options['time']                       = datetime.datetime(2014, 1, 1, 15, 0, 0, 0) 
+
+        session_id = proctorserv.make_reservation(options)
+        opts = collections.OrderedDict()
+        opts['session_id'] = session_id 
+
+        response = proctorserv.get_launch_parameters(opts)
+        print response
+        self.assertTrue(len(response) > 1)
 
 
 
